==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/SelectedItemChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedItemChangedEventArgsDescription } from "./SelectedItemChangedEventArgsDescription";
/**
 * @hidden
 */
var SelectedItemChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SelectedItemChangedEventArgsDescriptionMetadata, _super);
    function SelectedItemChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SelectedItemChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SelectedItemChangedEventArgsDescriptionMetadata.a == null) {
            SelectedItemChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SelectedItemChangedEventArgsDescriptionMetadata.c(SelectedItemChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(SelectedItemChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(SelectedItemChangedEventArgsDescriptionMetadata.a);
    };
    SelectedItemChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldItem", "Unknown");
        a.item("NewItem", "Unknown");
    };
    SelectedItemChangedEventArgsDescriptionMetadata.d = function (a) {
        SelectedItemChangedEventArgsDescriptionMetadata.b(a);
        a.aa("SelectedItemChangedEventArgs", function () { return new SelectedItemChangedEventArgsDescription(); });
        a.z("SelectedItemChangedEventArgs", SelectedItemChangedEventArgsDescriptionMetadata.a);
    };
    SelectedItemChangedEventArgsDescriptionMetadata.$t = markType(SelectedItemChangedEventArgsDescriptionMetadata, 'SelectedItemChangedEventArgsDescriptionMetadata');
    SelectedItemChangedEventArgsDescriptionMetadata.a = null;
    return SelectedItemChangedEventArgsDescriptionMetadata;
}(Base));
export { SelectedItemChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/SelectedItemChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedItemChangedEventArgsDescription } from "./SelectedItemChangedEventArgsDescription";
/**
 * @hidden
 */
var SelectedItemChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SelectedItemChangedEventArgsDescriptionMetadata, _super);
    function SelectedItemChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SelectedItemChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SelectedItemChangedEventArgsDescriptionMetadata.a == null) {
            SelectedItemChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SelectedItemChangedEventArgsDescriptionMetadata.c(SelectedItemChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(SelectedItemChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(SelectedItemChangedEventArgsDescriptionMetadata.a);
    };
    SelectedItemChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldItem", "Unknown");
        a.item("NewItem", "Unknown");
    };
    SelectedItemChangedEventArgsDescriptionMetadata.d = function (a) {
        SelectedItemChangedEventArgsDescriptionMetadata.b(a);
        a.ac("SelectedItemChangedEventArgs", function () { return new SelectedItemChangedEventArgsDescription(); });
        a.ab("SelectedItemChangedEventArgs", SelectedItemChangedEventArgsDescriptionMetadata.a);
    };
    SelectedItemChangedEventArgsDescriptionMetadata.$t = markType(SelectedItemChangedEventArgsDescriptionMetadata, 'SelectedItemChangedEventArgsDescriptionMetadata');
    SelectedItemChangedEventArgsDescriptionMetadata.a = null;
    return SelectedItemChangedEventArgsDescriptionMetadata;
}(Base));
export { SelectedItemChangedEventArgsDescriptionMetadata };
